==> jc-1.4.0.tar.gz: java/awt/image/LookupTable.h <==
// public abstract class java.awt.image.LookupTable

// class file dependencies
// @dep_class a552b3bb67ab409f java_awt_image_LookupTable
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_image_LookupTable_H_
#define _JC_java_awt_image_LookupTable_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_image_LookupTable$sub_refs	_jc_java_awt_image_LookupTable$sub_refs;
typedef struct _jc_java_awt_image_LookupTable$sub_nonrefs	_jc_java_awt_image_LookupTable$sub_nonrefs;
typedef struct _jc_java_awt_image_LookupTable$refs	_jc_java_awt_image_LookupTable$refs;
typedef struct _jc_java_awt_image_LookupTable$nonrefs	_jc_java_awt_image_LookupTable$nonrefs;
typedef struct _jc_java_awt_image_LookupTable$object	_jc_java_awt_image_LookupTable$object;

typedef const struct _jc_java_awt_image_LookupTable$vmethods	_jc_java_awt_image_LookupTable$vmethods;
typedef const struct _jc_java_awt_image_LookupTable$vtable	_jc_java_awt_image_LookupTable$vtable;
typedef const struct _jc_java_awt_image_LookupTable$vtype	_jc_java_awt_image_LookupTable$vtype;

// Constructors
extern void _jc_java_awt_image_LookupTable$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_java_awt_image_LookupTable$object *, jint, jint);

// Virtual methods
extern jint _jc_java_awt_image_LookupTable$method$getNumComponents$61e8905d7801e54e(_jc_env *, struct _jc_java_awt_image_LookupTable$object *);
extern jint _jc_java_awt_image_LookupTable$method$getOffset$520eb02cb0855546(_jc_env *, struct _jc_java_awt_image_LookupTable$object *);
extern _jc_int_array *_jc_java_awt_image_LookupTable$method$lookupPixel$0f1f0c9450fe78a3(_jc_env *, struct _jc_java_awt_image_LookupTable$object *, struct _jc_int_array *, struct _jc_int_array *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_LookupTable$method_info$getNumComponents$61e8905d7801e54e;
extern _jc_method _jc_java_awt_image_LookupTable$method_info$getOffset$520eb02cb0855546;
extern _jc_method _jc_java_awt_image_LookupTable$method_info$lookupPixel$0f1f0c9450fe78a3;

// Virtual methods structure
struct _jc_java_awt_image_LookupTable$vmethods {
	jint	(*getNumComponents$61e8905d7801e54e)(_jc_env *, struct _jc_java_awt_image_LookupTable$object *);
	jint	(*getOffset$520eb02cb0855546)(_jc_env *, struct _jc_java_awt_image_LookupTable$object *);
	_jc_int_array	*(*lookupPixel$0f1f0c9450fe78a3)(_jc_env *, struct _jc_java_awt_image_LookupTable$object *, struct _jc_int_array *, struct _jc_int_array *);
};

// Vtable
struct _jc_java_awt_image_LookupTable$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_LookupTable$vmethods	java_awt_image_LookupTable;
};

// Vtype
struct _jc_java_awt_image_LookupTable$vtype {
	_jc_type			type;
	_jc_java_awt_image_LookupTable$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_LookupTable$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_image_LookupTable$refs {
    _jc_java_awt_image_LookupTable$sub_refs	java_awt_image_LookupTable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_LookupTable$sub_nonrefs {
	jint	offset;
	jint	numComponents;
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_LookupTable$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_LookupTable$sub_nonrefs	java_awt_image_LookupTable;
};

// Object instance structure
struct _jc_java_awt_image_LookupTable$object {
	_jc_java_awt_image_LookupTable$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_LookupTable$vtype	*vtype;
	_jc_java_awt_image_LookupTable$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_LookupTable$vtype _jc_java_awt_image_LookupTable$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_LookupTable, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_LookupTable$class_object;

#endif	/* _JC_java_awt_image_LookupTable_H_ */

==> jc-1.4.6.tar.gz: java/awt/image/LookupTable.h <==
// public abstract class java.awt.image.LookupTable

// class file dependencies
// @dep_class a552b3bb67ab409f java_awt_image_LookupTable
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_image_LookupTable_H_
#define _JC_java_awt_image_LookupTable_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_image_LookupTable$sub_refs	_jc_java_awt_image_LookupTable$sub_refs;
typedef struct _jc_java_awt_image_LookupTable$sub_nonrefs	_jc_java_awt_image_LookupTable$sub_nonrefs;
typedef struct _jc_java_awt_image_LookupTable$refs	_jc_java_awt_image_LookupTable$refs;
typedef struct _jc_java_awt_image_LookupTable$nonrefs	_jc_java_awt_image_LookupTable$nonrefs;
typedef struct _jc_java_awt_image_LookupTable$object	_jc_java_awt_image_LookupTable$object;

typedef const struct _jc_java_awt_image_LookupTable$vmethods	_jc_java_awt_image_LookupTable$vmethods;
typedef const struct _jc_java_awt_image_LookupTable$vtable	_jc_java_awt_image_LookupTable$vtable;
typedef const struct _jc_java_awt_image_LookupTable$vtype	_jc_java_awt_image_LookupTable$vtype;

// Constructors
extern void _jc_java_awt_image_LookupTable$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_java_awt_image_LookupTable$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_awt_image_LookupTable$method$getNumComponents$61e8905d7801e54e(_jc_env *, struct _jc_java_awt_image_LookupTable$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_image_LookupTable$method$getOffset$520eb02cb0855546(_jc_env *, struct _jc_java_awt_image_LookupTable$object *) _JC_JCNI_ATTR;
extern _jc_int_array *_jc_java_awt_image_LookupTable$method$lookupPixel$0f1f0c9450fe78a3(_jc_env *, struct _jc_java_awt_image_LookupTable$object *, struct _jc_int_array *, struct _jc_int_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_LookupTable$method_info$getNumComponents$61e8905d7801e54e;
extern _jc_method _jc_java_awt_image_LookupTable$method_info$getOffset$520eb02cb0855546;
extern _jc_method _jc_java_awt_image_LookupTable$method_info$lookupPixel$0f1f0c9450fe78a3;

// Virtual methods structure
struct _jc_java_awt_image_LookupTable$vmethods {
	jint	(*getNumComponents$61e8905d7801e54e)(_jc_env *, struct _jc_java_awt_image_LookupTable$object *) _JC_JCNI_ATTR;
	jint	(*getOffset$520eb02cb0855546)(_jc_env *, struct _jc_java_awt_image_LookupTable$object *) _JC_JCNI_ATTR;
	_jc_int_array	*(*lookupPixel$0f1f0c9450fe78a3)(_jc_env *, struct _jc_java_awt_image_LookupTable$object *, struct _jc_int_array *, struct _jc_int_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_image_LookupTable$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_LookupTable$vmethods	java_awt_image_LookupTable;
};

// Vtype
struct _jc_java_awt_image_LookupTable$vtype {
	_jc_type			type;
	_jc_java_awt_image_LookupTable$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_LookupTable$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_image_LookupTable$refs {
    _jc_java_awt_image_LookupTable$sub_refs	java_awt_image_LookupTable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_LookupTable$sub_nonrefs {
	jint	offset;
	jint	numComponents;
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_LookupTable$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_LookupTable$sub_nonrefs	java_awt_image_LookupTable;
};

// Object instance structure
struct _jc_java_awt_image_LookupTable$object {
	_jc_java_awt_image_LookupTable$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_LookupTable$vtype	*vtype;
	_jc_java_awt_image_LookupTable$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_LookupTable$vtype _jc_java_awt_image_LookupTable$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_LookupTable, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_LookupTable$class_object;

#endif	/* _JC_java_awt_image_LookupTable_H_ */
